==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QPixmapCache_Key_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpixmapcache.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPixmapCache_Key(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPixmapCache::Key")
    QPixmapCache::Key *_ptr = reinterpret_cast<QPixmapCache::Key *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Key()
void __qt_construct_QPixmapCache_Key_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Key()")
    Q_UNUSED(__java_arguments)
    QPixmapCache::Key *__qt_this = new(__qtjambi_ptr) QPixmapCache::Key();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new Key(QPixmapCache::Key)
void __qt_construct_QPixmapCache_Key_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Key(QPixmapCache::Key)")
    jobject other0 = __java_arguments[0].l;
    const QPixmapCache::Key& __qt_other0 = qtjambi_cast<const QPixmapCache::Key& >(__jni_env, other0);
    QPixmapCache::Key *__qt_this = new(__qtjambi_ptr) QPixmapCache::Key(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPixmapCache::Key
void __qt_destruct_QPixmapCache_Key(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPixmapCache::Key")
    reinterpret_cast<QPixmapCache::Key*>(ptr)->~Key();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPixmapCache::Key::Key()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_initialize_1native__Lio_qt_gui_QPixmapCache_00024Key_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::Key::Key()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache_Key_0, sizeof(QPixmapCache::Key), typeid(QPixmapCache::Key), false, &deleter_QPixmapCache_Key, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::Key(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_initialize_1native__Lio_qt_gui_QPixmapCache_00024Key_2Lio_qt_gui_QPixmapCache_00024Key_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::Key::Key(QPixmapCache::Key)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache_Key_1, sizeof(QPixmapCache::Key), typeid(QPixmapCache::Key), false, &deleter_QPixmapCache_Key, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::Key::operator=(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_assign_1native_1cref_1QPixmapCache_1Key__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::operator=(QPixmapCache::Key)", __qt_this)
        const QPixmapCache::Key& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::operator==(QPixmapCache::Key)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_operator_1equal_1native_1cref_1QPixmapCache_1Key_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID key0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::operator==(QPixmapCache::Key)const", __qt_this)
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        __java_return_value = (*__qt_this) == __qt_key0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::Key::swap(QPixmapCache::Key&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_swap_1native_1ref_1QPixmapCache_1Key__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::swap(QPixmapCache::Key&)", __qt_this)
        QPixmapCache::Key& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPixmapCache::Key>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPixmapCache_Key(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPixmapCache::Key>("QPixmapCache::Key", "io/qt/gui/QPixmapCache$Key");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPixmapCache_Key, {
        ConstructorInfo(&__qt_construct_QPixmapCache_Key_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPixmapCache_Key_1, "Lio/qt/gui/QPixmapCache$Key;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPixmapCache_Key);
    registerMetaType<QPixmapCache::Key>("QPixmapCache::Key");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPixmapCache_Key_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpixmapcache.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPixmapCache_Key(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPixmapCache::Key")
    QPixmapCache::Key *_ptr = reinterpret_cast<QPixmapCache::Key *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Key()
void __qt_construct_QPixmapCache_Key_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Key()")
    Q_UNUSED(__java_arguments)
    QPixmapCache::Key *__qt_this = new(__qtjambi_ptr) QPixmapCache::Key();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new Key(QPixmapCache::Key)
void __qt_construct_QPixmapCache_Key_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Key(QPixmapCache::Key)")
    jobject other0 = __java_arguments[0].l;
    const QPixmapCache::Key& __qt_other0 = qtjambi_cast<const QPixmapCache::Key& >(__jni_env, other0);
    QPixmapCache::Key *__qt_this = new(__qtjambi_ptr) QPixmapCache::Key(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPixmapCache::Key
void __qt_destruct_QPixmapCache_Key(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPixmapCache::Key")
    reinterpret_cast<QPixmapCache::Key*>(ptr)->~Key();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPixmapCache::Key::Key()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_initialize_1native__Lio_qt_gui_QPixmapCache_00024Key_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::Key::Key()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache_Key_0, sizeof(QPixmapCache::Key), typeid(QPixmapCache::Key), false, &deleter_QPixmapCache_Key, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::Key(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_initialize_1native__Lio_qt_gui_QPixmapCache_00024Key_2Lio_qt_gui_QPixmapCache_00024Key_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPixmapCache::Key::Key(QPixmapCache::Key)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPixmapCache_Key_1, sizeof(QPixmapCache::Key), typeid(QPixmapCache::Key), false, &deleter_QPixmapCache_Key, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::Key::operator=(QPixmapCache::Key)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_assign_1native_1cref_1QPixmapCache_1Key__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::operator=(QPixmapCache::Key)", __qt_this)
        const QPixmapCache::Key& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPixmapCache::Key::operator==(QPixmapCache::Key)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_equals_1native_1cref_1QPixmapCache_1Key_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID key0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::operator==(QPixmapCache::Key)const", __qt_this)
        const QPixmapCache::Key& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QPixmapCache::Key>(key0);
        __java_return_value = (*__qt_this) == __qt_key0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPixmapCache::Key::swap(QPixmapCache::Key&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_swap_1native_1ref_1QPixmapCache_1Key__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPixmapCache::Key::swap(QPixmapCache::Key&)", __qt_this)
        QPixmapCache::Key& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPixmapCache::Key>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPixmapCache_00024Key_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPixmapCache::Key *__qt_this = QtJambiAPI::objectFromNativeId<QPixmapCache::Key>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPixmapCache_Key(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPixmapCache::Key>("QPixmapCache::Key", "io/qt/gui/QPixmapCache$Key");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPixmapCache_Key, {
        ConstructorInfo(&__qt_construct_QPixmapCache_Key_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPixmapCache_Key_1, "Lio/qt/gui/QPixmapCache$Key;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPixmapCache_Key);
    registerMetaType<QPixmapCache::Key>("QPixmapCache::Key");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
